@@ -11,10 +11,8 @@
  */
 package org.eclipse.che.api.factory.server.bitbucket;
 
-import static org.eclipse.che.api.factory.shared.Constants.CURRENT_VERSION;
 import static org.eclipse.che.api.factory.shared.Constants.URL_PARAMETER_NAME;
 import static org.eclipse.che.dto.server.DtoFactory.newDto;
-import static org.eclipse.che.security.oauth1.OAuthAuthenticationService.ERROR_QUERY_NAME;
 
 import jakarta.validation.constraints.NotNull;
 import java.util.Map;
@@ -22,6 +20,7 @@ import javax.inject.Inject;
 import javax.inject.Singleton;
 import org.eclipse.che.api.core.ApiException;
 import org.eclipse.che.api.core.BadRequestException;
+import org.eclipse.che.api.factory.server.BaseFactoryParameterResolver;
 import org.eclipse.che.api.factory.server.FactoryParametersResolver;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
 import org.eclipse.che.api.factory.server.urlfactory.ProjectConfigDtoMerger;
@@ -35,10 +34,14 @@ import org.eclipse.che.api.factory.shared.dto.ScmInfoDto;
 import org.eclipse.che.api.workspace.server.devfile.URLFetcher;
 import org.eclipse.che.api.workspace.shared.dto.ProjectConfigDto;
 import org.eclipse.che.api.workspace.shared.dto.devfile.ProjectDto;
+import org.eclipse.che.security.oauth.AuthorisationRequestManager;
 
 /** Provides Factory Parameters resolver for bitbucket repositories. */
 @Singleton
-public class BitbucketFactoryParametersResolver implements FactoryParametersResolver {
+public class BitbucketFactoryParametersResolver extends BaseFactoryParameterResolver
+    implements FactoryParametersResolver {
+
+  private static final String PROVIDER_NAME = "bitbucket";
 
   /** Parser which will allow to check validity of URLs and create objects. */
   private final BitbucketURLParser bitbucketURLParser;
@@ -64,7 +67,9 @@ public class BitbucketFactoryParametersResolver implements FactoryParametersReso
       URLFactoryBuilder urlFactoryBuilder,
       ProjectConfigDtoMerger projectConfigDtoMerger,
       PersonalAccessTokenManager personalAccessTokenManager,
-      BitbucketApiClient bitbucketApiClient) {
+      BitbucketApiClient bitbucketApiClient,
+      AuthorisationRequestManager authorisationRequestManager) {
+    super(authorisationRequestManager, urlFactoryBuilder, PROVIDER_NAME);
     this.bitbucketURLParser = bitbucketURLParser;
     this.urlFetcher = urlFetcher;
     this.bitbucketSourceStorageBuilder = bitbucketSourceStorageBuilder;
@@ -88,6 +93,11 @@ public class BitbucketFactoryParametersResolver implements FactoryParametersReso
         && bitbucketURLParser.isValid(factoryParameters.get(URL_PARAMETER_NAME));
   }
 
+  @Override
+  public String getProviderName() {
+    return PROVIDER_NAME;
+  }
+
   /**
    * Create factory object based on provided parameters
    *
@@ -100,19 +110,13 @@ public class BitbucketFactoryParametersResolver implements FactoryParametersReso
     // no need to check null value of url parameter as accept() method has performed the check
     final BitbucketUrl bitbucketUrl =
         bitbucketURLParser.parse(factoryParameters.get(URL_PARAMETER_NAME));
-    boolean skipAuthentication =
-        factoryParameters.get(ERROR_QUERY_NAME) != null
-            && factoryParameters.get(ERROR_QUERY_NAME).equals("access_denied");
     // create factory from the following location if location exists, else create default factory
-    return urlFactoryBuilder
-        .createFactoryFromDevfile(
-            bitbucketUrl,
-            new BitbucketAuthorizingFileContentProvider(
-                bitbucketUrl, urlFetcher, personalAccessTokenManager, bitbucketApiClient),
-            extractOverrideParams(factoryParameters),
-            skipAuthentication)
-        .orElseGet(() -> newDto(FactoryDto.class).withV(CURRENT_VERSION).withSource("repo"))
-        .acceptVisitor(new BitbucketFactoryVisitor(bitbucketUrl));
+    return createFactory(
+        factoryParameters,
+        bitbucketUrl,
+        new BitbucketFactoryVisitor(bitbucketUrl),
+        new BitbucketAuthorizingFileContentProvider(
+            bitbucketUrl, urlFetcher, personalAccessTokenManager, bitbucketApiClient));
   }
 
   /**
