@@ -45,7 +45,7 @@ public class GithubAuthorizingFileContentProviderTest {
     URLFetcher urlFetcher = mock(URLFetcher.class);
 
     GithubUrl githubUrl =
-        new GithubUrl()
+        new GithubUrl("github")
             .withUsername("eclipse")
             .withRepository("che")
             .withBranch("main")
@@ -54,7 +54,7 @@ public class GithubAuthorizingFileContentProviderTest {
     FileContentProvider fileContentProvider =
         new GithubAuthorizingFileContentProvider(githubUrl, urlFetcher, personalAccessTokenManager);
 
-    when(personalAccessTokenManager.get(anyString()))
+    when(personalAccessTokenManager.getAndStore(anyString()))
         .thenReturn(new PersonalAccessToken("foo", "che", "my-token"));
 
     fileContentProvider.fetchContent("devfile.yaml");
@@ -71,7 +71,7 @@ public class GithubAuthorizingFileContentProviderTest {
     String raw_url = "https://raw.githubusercontent.com/foo/bar/branch-name/devfile.yaml";
 
     GithubUrl githubUrl =
-        new GithubUrl()
+        new GithubUrl("github")
             .withUsername("eclipse")
             .withRepository("che")
             .withBranch("main")
@@ -81,7 +81,7 @@ public class GithubAuthorizingFileContentProviderTest {
     FileContentProvider fileContentProvider =
         new GithubAuthorizingFileContentProvider(githubUrl, urlFetcher, personalAccessTokenManager);
 
-    when(personalAccessTokenManager.get(anyString()))
+    when(personalAccessTokenManager.getAndStore(anyString()))
         .thenReturn(new PersonalAccessToken(raw_url, "che", "my-token"));
 
     fileContentProvider.fetchContent(raw_url);
@@ -92,13 +92,14 @@ public class GithubAuthorizingFileContentProviderTest {
   public void shouldThrowNotFoundForPublicRepos() throws Exception {
     String url = "https://raw.githubusercontent.com/foo/bar/branch-name/devfile.yaml";
 
-    GithubUrl githubUrl = new GithubUrl().withUsername("eclipse").withRepository("che");
+    GithubUrl githubUrl = new GithubUrl("github").withUsername("eclipse").withRepository("che");
 
     URLFetcher urlFetcher = Mockito.mock(URLFetcher.class);
     FileContentProvider fileContentProvider =
         new GithubAuthorizingFileContentProvider(githubUrl, urlFetcher, personalAccessTokenManager);
 
-    when(personalAccessTokenManager.get(anyString())).thenThrow(UnknownScmProviderException.class);
+    when(personalAccessTokenManager.getAndStore(anyString()))
+        .thenThrow(UnknownScmProviderException.class);
 
     when(urlFetcher.fetch(eq(url))).thenThrow(FileNotFoundException.class);
 
@@ -108,13 +109,14 @@ public class GithubAuthorizingFileContentProviderTest {
   @Test(expectedExceptions = DevfileException.class)
   public void shouldThrowDevfileException() throws Exception {
     String url = "https://raw.githubusercontent.com/foo/bar/branch-name/devfile.yaml";
-    GithubUrl githubUrl = new GithubUrl().withUsername("eclipse").withRepository("che");
+    GithubUrl githubUrl = new GithubUrl("github").withUsername("eclipse").withRepository("che");
 
     URLFetcher urlFetcher = Mockito.mock(URLFetcher.class);
     FileContentProvider fileContentProvider =
         new GithubAuthorizingFileContentProvider(githubUrl, urlFetcher, personalAccessTokenManager);
 
-    when(personalAccessTokenManager.get(anyString())).thenThrow(UnknownScmProviderException.class);
+    when(personalAccessTokenManager.getAndStore(anyString()))
+        .thenThrow(UnknownScmProviderException.class);
     when(urlFetcher.fetch(eq(url))).thenThrow(FileNotFoundException.class);
     when(urlFetcher.fetch(eq("https://github.com/eclipse/che"))).thenThrow(IOException.class);
 
@@ -126,11 +128,11 @@ public class GithubAuthorizingFileContentProviderTest {
     String raw_url = "https://ghserver.com/foo/bar/branch-name/devfile.yaml";
 
     URLFetcher urlFetcher = Mockito.mock(URLFetcher.class);
-    GithubUrl githubUrl = new GithubUrl().withUsername("eclipse").withRepository("che");
+    GithubUrl githubUrl = new GithubUrl("github").withUsername("eclipse").withRepository("che");
     FileContentProvider fileContentProvider =
         new GithubAuthorizingFileContentProvider(githubUrl, urlFetcher, personalAccessTokenManager);
     var personalAccessToken = new PersonalAccessToken(raw_url, "che", "my-token");
-    when(personalAccessTokenManager.get(anyString())).thenReturn(personalAccessToken);
+    when(personalAccessTokenManager.getAndStore(anyString())).thenReturn(personalAccessToken);
 
     fileContentProvider.fetchContent(raw_url);
 
