@@ -51,6 +51,7 @@ import org.eclipse.che.api.workspace.shared.dto.devfile.DevfileDto;
 import org.eclipse.che.api.workspace.shared.dto.devfile.MetadataDto;
 import org.eclipse.che.api.workspace.shared.dto.devfile.ProjectDto;
 import org.eclipse.che.api.workspace.shared.dto.devfile.SourceDto;
+import org.eclipse.che.security.oauth.AuthorisationRequestManager;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
@@ -88,6 +89,7 @@ public class GithubFactoryParametersResolverTest {
   private URLFactoryBuilder urlFactoryBuilder;
 
   @Mock private PersonalAccessTokenManager personalAccessTokenManager;
+  @Mock private AuthorisationRequestManager authorisationRequestManager;
 
   /**
    * Capturing the location parameter when calling {@link
@@ -97,7 +99,7 @@ public class GithubFactoryParametersResolverTest {
   @Captor private ArgumentCaptor<RemoteFactoryUrl> factoryUrlArgumentCaptor;
 
   /** Instance of resolver that will be tested. */
-  private GithubFactoryParametersResolver githubFactoryParametersResolver;
+  private AbstractGithubFactoryParametersResolver abstractGithubFactoryParametersResolver;
 
   @BeforeMethod
   protected void init() throws Exception {
@@ -108,22 +110,23 @@ public class GithubFactoryParametersResolverTest {
         new GithubURLParser(
             personalAccessTokenManager, devfileFilenamesProvider, githubApiClient, null, false);
 
-    githubFactoryParametersResolver =
+    abstractGithubFactoryParametersResolver =
         new GithubFactoryParametersResolver(
             githubUrlParser,
             urlFetcher,
             githubSourceStorageBuilder,
+            authorisationRequestManager,
             urlFactoryBuilder,
             projectConfigDtoMerger,
             personalAccessTokenManager);
-    assertNotNull(this.githubFactoryParametersResolver);
+    assertNotNull(this.abstractGithubFactoryParametersResolver);
   }
 
   /** Check missing parameter name can't be accepted by this resolver */
   @Test
   public void checkMissingParameter() {
     Map<String, String> parameters = singletonMap("foo", "this is a foo bar");
-    boolean accept = githubFactoryParametersResolver.accept(parameters);
+    boolean accept = abstractGithubFactoryParametersResolver.accept(parameters);
     // shouldn't be accepted
     assertFalse(accept);
   }
@@ -132,7 +135,7 @@ public class GithubFactoryParametersResolverTest {
   @Test
   public void checkInvalidAcceptUrl() {
     Map<String, String> parameters = singletonMap(URL_PARAMETER_NAME, "http://www.eclipse.org/che");
-    boolean accept = githubFactoryParametersResolver.accept(parameters);
+    boolean accept = abstractGithubFactoryParametersResolver.accept(parameters);
     // shouldn't be accepted
     assertFalse(accept);
   }
@@ -142,7 +145,7 @@ public class GithubFactoryParametersResolverTest {
   public void checkValidAcceptUrl() {
     Map<String, String> parameters =
         singletonMap(URL_PARAMETER_NAME, "https://github.com/codenvy/codenvy.git");
-    boolean accept = githubFactoryParametersResolver.accept(parameters);
+    boolean accept = abstractGithubFactoryParametersResolver.accept(parameters);
     // shouldn't be accepted
     assertTrue(accept);
   }
@@ -165,7 +168,7 @@ public class GithubFactoryParametersResolverTest {
 
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, githubUrl);
     // when
-    FactoryDto factory = (FactoryDto) githubFactoryParametersResolver.createFactory(params);
+    FactoryDto factory = (FactoryDto) abstractGithubFactoryParametersResolver.createFactory(params);
     // then
     verify(urlFactoryBuilder).buildDefaultDevfile(eq("che"));
     assertEquals(factory, computedFactory);
@@ -190,7 +193,7 @@ public class GithubFactoryParametersResolverTest {
             "https://github.com/eclipse/che",
             ERROR_QUERY_NAME,
             "access_denied");
-    githubFactoryParametersResolver.createFactory(params);
+    abstractGithubFactoryParametersResolver.createFactory(params);
     // then
     verify(urlFactoryBuilder)
         .createFactoryFromDevfile(
@@ -207,7 +210,7 @@ public class GithubFactoryParametersResolverTest {
         .thenReturn(new GithubCommit().withSha("test-sha"));
 
     // when
-    githubFactoryParametersResolver.createFactory(
+    abstractGithubFactoryParametersResolver.createFactory(
         ImmutableMap.of(URL_PARAMETER_NAME, "https://github.com/eclipse/che"));
     // then
     verify(urlFactoryBuilder)
@@ -234,7 +237,7 @@ public class GithubFactoryParametersResolverTest {
 
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, githubUrl);
     // when
-    FactoryDto factory = (FactoryDto) githubFactoryParametersResolver.createFactory(params);
+    FactoryDto factory = (FactoryDto) abstractGithubFactoryParametersResolver.createFactory(params);
     // then
     assertNotNull(factory.getDevfile());
     assertNull(factory.getWorkspace());
@@ -265,7 +268,7 @@ public class GithubFactoryParametersResolverTest {
 
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, githubUrl);
     // when
-    FactoryDto factory = (FactoryDto) githubFactoryParametersResolver.createFactory(params);
+    FactoryDto factory = (FactoryDto) abstractGithubFactoryParametersResolver.createFactory(params);
     // then
     assertNotNull(factory.getDevfile());
     SourceDto source = factory.getDevfile().getProjects().get(0).getSource();
@@ -296,7 +299,7 @@ public class GithubFactoryParametersResolverTest {
 
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, githubUrl);
     // when
-    FactoryDto factory = (FactoryDto) githubFactoryParametersResolver.createFactory(params);
+    FactoryDto factory = (FactoryDto) abstractGithubFactoryParametersResolver.createFactory(params);
     // then
     assertNotNull(factory.getDevfile());
     SourceDto source = factory.getDevfile().getProjects().get(0).getSource();
@@ -320,7 +323,7 @@ public class GithubFactoryParametersResolverTest {
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, githubUrl);
     // when
     FactoryDevfileV2Dto factory =
-        (FactoryDevfileV2Dto) githubFactoryParametersResolver.createFactory(params);
+        (FactoryDevfileV2Dto) abstractGithubFactoryParametersResolver.createFactory(params);
     // then
     ScmInfo scmInfo = factory.getScmInfo();
     assertNotNull(scmInfo);
@@ -340,7 +343,7 @@ public class GithubFactoryParametersResolverTest {
         .thenReturn(Optional.of(generateDevfileFactory()));
 
     // when
-    githubFactoryParametersResolver.createFactory(params);
+    abstractGithubFactoryParametersResolver.createFactory(params);
 
     // then
     verify(urlFactoryBuilder)
@@ -351,6 +354,50 @@ public class GithubFactoryParametersResolverTest {
             eq(true));
   }
 
+  @Test
+  public void shouldParseFactoryUrlWithAuthentication() throws Exception {
+    // given
+    githubUrlParser = mock(GithubURLParser.class);
+
+    abstractGithubFactoryParametersResolver =
+        new GithubFactoryParametersResolver(
+            githubUrlParser,
+            urlFetcher,
+            githubSourceStorageBuilder,
+            authorisationRequestManager,
+            urlFactoryBuilder,
+            projectConfigDtoMerger,
+            personalAccessTokenManager);
+    when(authorisationRequestManager.isStored(eq("github"))).thenReturn(true);
+    // when
+    abstractGithubFactoryParametersResolver.parseFactoryUrl("url");
+    // then
+    verify(githubUrlParser).parseWithoutAuthentication("url");
+    verify(githubUrlParser, never()).parse("url");
+  }
+
+  @Test
+  public void shouldParseFactoryUrlWithOutAuthentication() throws Exception {
+    // given
+    githubUrlParser = mock(GithubURLParser.class);
+
+    abstractGithubFactoryParametersResolver =
+        new GithubFactoryParametersResolver(
+            githubUrlParser,
+            urlFetcher,
+            githubSourceStorageBuilder,
+            authorisationRequestManager,
+            urlFactoryBuilder,
+            projectConfigDtoMerger,
+            personalAccessTokenManager);
+    when(authorisationRequestManager.isStored(eq("github"))).thenReturn(false);
+    // when
+    abstractGithubFactoryParametersResolver.parseFactoryUrl("url");
+    // then
+    verify(githubUrlParser).parse("url");
+    verify(githubUrlParser, never()).parseWithoutAuthentication("url");
+  }
+
   private FactoryDto generateDevfileFactory() {
     return newDto(FactoryDto.class)
         .withV(CURRENT_VERSION)
